[PATCH 7/8] improve-style-neo1973_resume_reason.patch

Nelson Castillo nelsoneci at gmail.com
Thu Oct 16 19:01:21 CEST 2008


Small style improvement.
Changed strings for consistency.

Signed-off-by: Nelson Castillo <nelsoneci at gmail.com>
---

 0 files changed, 0 insertions(+), 0 deletions(-)

diff --git a/arch/arm/plat-s3c24xx/neo1973_pm_resume_reason.c b/arch/arm/plat-s3c24xx/neo1973_pm_resume_reason.c
index c7730b6..e8462a0 100644
--- a/arch/arm/plat-s3c24xx/neo1973_pm_resume_reason.c
+++ b/arch/arm/plat-s3c24xx/neo1973_pm_resume_reason.c
@@ -1,5 +1,5 @@
 /*
  * Resume reason sysfs for the FIC Neo1973 GSM Phone
  *
  * (C) 2008 by Openmoko Inc.
  * Author: Andy Green <andy at openmoko.com>
@@ -73,10 +73,14 @@ static ssize_t resume_reason_read(struct device *dev,
 	int gta = !!machine_is_neo1973_gta02();
 
 	for (bit = 0; resume_reasons[gta][bit]; bit++) {
-		if ((*gstatus4_mapped) & (1 << bit))
-			end += sprintf(end, "* %s\n", resume_reasons[gta][bit]);
-		else
-			end += sprintf(end, "  %s\n", resume_reasons[gta][bit]);
+		if ((*gstatus4_mapped) & (1 << bit)) {
+			end += sprintf(end, "* %s\n",
+				       resume_reasons[gta][bit]);
+		}
+		else {
+			end += sprintf(end, "  %s\n",
+				       resume_reasons[gta][bit]);
+		}
 
 #ifdef CONFIG_MACH_NEO1973_GTA02
 		if ((gta) && (bit == 9)) /* PMU */
@@ -144,4 +148,4 @@ module_exit(neo1973_resume_reason_exit);
 
 MODULE_LICENSE("GPL");
 MODULE_AUTHOR("Andy Green <andy at openmoko.com>");
-MODULE_DESCRIPTION("Neo1973 resume_reason");
+MODULE_DESCRIPTION("Openmoko GTA01/GTA02 resume_reason");
@@ -1,5 +1,5 @@
 /*
- * Resume reason sysfs for the FIC Neo1973 GSM Phone
+ * Resume reason sysfs for the Openmoko GTA01/GTA02 GSM Phone
  *
  * (C) 2008 by Openmoko Inc.




More information about the openmoko-kernel mailing list